==> jekyll-3.2.1.tar.gz: jekyll-3.2.1/.github/ISSUE_TEMPLATE.md <==
<!--
  Hi! Thanks for considering to file a bug with Jekyll. Please take the time to
  answer the basic questions. You can convert `[ ]` into `[x]` to check boxes (or submit
  and check.) If there is no need for certain fields like output and redirection, please delete
  those headers before submitting. We know not all tickets require those steps.
  Otherwise, please try to be as detailed as possible.
  
  If you are unsure this is a bug in Jekyll, or this is a bug caused
  by a plugin that isn't directly related to Jekyll, or if this is just
  a generic usage question, please consider asking your question at
  https://talk.jekyllrb.com where non-bug questions go.
  
  Thanks!
-->

- [ ] I believe this to be a bug, not a question about using Jekyll.
- [ ] I Updated to the latest Jekyll (or) if on Github Pages to the latest `github-pages`
- [ ] I Read the CONTRIBUTION file at https://jekyllrb.com/docs/contributing/
- [ ] This is a feature request.

---

- [ ] I am on (or have tested on) ***macOS*** 10+
- [ ] I am on (or have tested on) ***Debian/Ubuntu*** GNU/Linux
- [ ] I am on (or have tested on) ***Fedora*** GNU/Linux
- [ ] I am on (or have tested on) ***Arch*** GNU/Linux
- [ ] I am on (or have tested on) ***Other*** GNU/Linux
- [ ] I am on (or have tested on) ***Windows*** 10+

<!--
  Other GNU/Linux includes Scientific GNU/Linux, CentOS GNU/Linux, and others.
  If you are on a minor sub-distro (such as ElementaryOS which does not diverge from
  Ubuntu much, please check the parent distro. Kubuntu, Edubuntu, Lubuntu should
  also be flagged as Ubuntu as their packages come from upstream Ubuntu.
-->

---

- [ ] I was trying to install.
- [ ] There is a broken Plugin API.
- [ ] I had an error on Github Pages, and I have not tested locally.
- [ ] I had an error on Github Pages, and Github Support said it was a Jekyll Bug.
- [ ] I had an error on Github Pages and I did not test it locally.
- [ ] I was trying to build.
- [ ] It was another bug.

## My Reproduction Steps

<!--
  If this error occured on Github Pages, please try to provide us with logs,
  and look at them yourself, to determine if this is an actual Jekyll bug. In
  the event you are unsure, file a ticket, however, when you do please provide
  the logs (strip them of personal information.)
  
  If you have trouble finding your logs, please email support@github.com and
  they will happily help you. If you cannot find logs, please try your best to
  replicate it locally because we cannot fix a problem if we do not know
  exactly what caused it, or within a relatively close distance.
-->

<!--
  Insert the steps you took to for this problem to exist. Such as the
  directories you created and, the full command you ran, and include any
  plugins you have installed, this is very important.
  
  If your steps are complicated, you can also submit a Github
  repository (please no zips, they will be removed and rejected by maintainers,)
  and just supply a command for us to reproduce it ourselves.
-->

## The Output I Wanted

<!-- 
  Insert the output from the command. Alter it as little as you can.
  The minimum should be personal information. Though we normally don't log
  anything like that so there should be no need to alter it.
-->

==> jekyll-3.6.2.tar.gz: jekyll-3.6.2/.github/ISSUE_TEMPLATE.md <==
<!--
  Hi! Thanks for considering to file a bug with Jekyll. Please take the time to
  answer the basic questions. You can convert `[ ]` into `[x]` to check boxes (or submit
  and check.) If there is no need for certain fields like output and redirection, please delete
  those headers before submitting. We know not all tickets require those steps.
  Otherwise, please try to be as detailed as possible.

  If you are unsure this is a bug in Jekyll, or this is a bug caused
  by a plugin that isn't directly related to Jekyll, or if this is just
  a generic usage question, please consider asking your question at
  https://talk.jekyllrb.com where non-bug questions go.

  Thanks!
-->

- [ ] I believe this to be a bug, not a question about using Jekyll.
- [ ] I updated to the latest Jekyll (or) if on GitHub Pages to the latest `github-pages`
- [ ] I ran `jekyll doctor` to check my configuration
- [ ] I read the CONTRIBUTION file at https://jekyllrb.com/docs/contributing/
- [ ] This is a feature request.

---

- [ ] I am on (or have tested on) ***macOS*** 10+
- [ ] I am on (or have tested on) ***Debian/Ubuntu*** GNU/Linux
- [ ] I am on (or have tested on) ***Fedora*** GNU/Linux
- [ ] I am on (or have tested on) ***Arch*** GNU/Linux
- [ ] I am on (or have tested on) ***Other*** GNU/Linux
- [ ] I am on (or have tested on) ***Windows*** 10+

<!--
  Other GNU/Linux includes Scientific GNU/Linux, CentOS GNU/Linux, and others.
  If you are on a minor sub-distro (such as ElementaryOS which does not diverge from
  Ubuntu much, please check the parent distro. Kubuntu, Edubuntu, Lubuntu should
  also be flagged as Ubuntu as their packages come from upstream Ubuntu.
-->

---

- [ ] I was trying to install.
- [ ] There is a broken Plugin API.
- [ ] I had an error on GitHub Pages, and I have reproduced it locally.
- [ ] I had an error on GitHub Pages, and GitHub Support said it was a Jekyll Bug.
- [ ] I had an error on GitHub Pages and I did not test it locally.
- [ ] I was trying to build.
- [ ] It was another bug.

## My Reproduction Steps

<!--
  If this error occured on GitHub Pages, please try to provide us with logs,
  and look at them yourself, to determine if this is an actual Jekyll bug. In
  the event you are unsure, file a ticket, however, when you do please provide
  the logs (strip them of personal information.)

  If you have trouble finding your logs, please email support@github.com and
  they will happily help you. If you cannot find logs, please try your best to
  replicate it locally because we cannot fix a problem if we do not know
  exactly what caused it, or within a relatively close distance.
-->

<!--
  Insert the steps you took to for this problem to exist. Such as the
  directories you created and, the full command you ran, and include any
  plugins you have installed, this is very important.

  If your steps are complicated, you can also submit a GitHub
  repository (please no zips, they will be removed and rejected by maintainers,)
  and just supply a command for us to reproduce it ourselves.
-->

## The Output I Wanted

<!--
  Insert the output from the command. Alter it as little as you can.
  The minimum should be personal information. Though we normally don't log
  anything like that so there should be no need to alter it.
-->
